<h3>Useful Links</h3>
<ul>
  <li><a href="https://wiki.openstack.org/wiki/Sahara">Sahara @ OpenStack Wiki</a></li>
  <li><a href="https://storyboard.openstack.org/#!/project_group/74">Sahara @ Storyboard</a></li>
</ul>

{% if READTHEDOCS %}
<script type='text/javascript'>
    $('div.body').css('margin', 0)
</script>
{% endif %}
